import React from 'react';
import { shallow, mount } from 'enzyme';
import { Provider } from "react-redux";
import { MemoryRouter } from 'react-router-dom';
import configureMockStore from "redux-mock-store";
import ProductDetailsPage from './ProductDetailsPage';
import ProductImages from './ProductImages';
import ProductDeatils from './ProductDetails';
import SimilarProduct from '../SimilarProducts/SimilarProducts'
jest.mock('react-awesome-slider', () => ({
  AwesomeSlider: ''
}))
jest.mock('react-awesome-slider/src/styles', () => ({
  AwesomeSliderStyles: ''
}))

const mockStore = configureMockStore();


const category = require('../../testData/testFixture.json');

const store = mockStore(category);

describe('Component : ProductDetailsPage', () => {

  it('expect to render ProductDetailsPage component', () => {
    const product = category.groups[0]
    const match = {
      params: {
        id: "belgian-linen-embroidery-duvet-cover-shams-slate-white-b3024"
      }
    }
    expect(shallow(<ProductDetailsPage categoryResult={product} match={match} />)).toMatchSnapshot();
  })

  it('verifying rendering of Product images component', () => {
    const match = {
      params: {
        id: "belgian-linen-embroidery-duvet-cover-shams-slate-white-b3024"
      }
    }
    const wrapper = mount(
      <MemoryRouter>
        <ProductDetailsPage categoryResult={category} match={match} />
      </MemoryRouter>
    )
    expect(wrapper.contains(<ProductImages product={category.groups[0]} />)).toBe(true);
  })

  it('verifying rendering of Product details component', () => {
    const match = {
      params: {
        id: "belgian-linen-embroidery-duvet-cover-shams-slate-white-b3024"
      }
    }
    const wrapper = mount(
      <MemoryRouter>
        <ProductDetailsPage categoryResult={category} match={match} />
      </MemoryRouter>
    )
    expect(wrapper.contains(<ProductDeatils product={category.groups[0]} />)).toBe(true);
  })

  it('verifying rendering of Similar Product component', () => {
    const match = {
      params: {
        id: "belgian-linen-embroidery-duvet-cover-shams-slate-white-b3024"
      }
    }
    const wrapper = mount(
      <MemoryRouter>
        <ProductDetailsPage categoryResult={category} match={match} />
      </MemoryRouter>
    )
    expect(wrapper.contains(<SimilarProduct categoryResult={category} />)).toBe(true);
  })

  it('verifying image loader display when data is loading', () => {
    const productlist = {}
    const wrapper = mount(<ProductDetailsPage categoryResult={productlist} />)
    expect(wrapper.find('img.loading-indicator').length).toBe(1);
  })
})
